@@ -15,3 +15,5 @@
 
 from .Construction import *
 from Advanced import *
+from Legends import *
+from MakeId import *
